<?php

namespace Drupal\monarch_multistep_field_group\Plugin\field_group\FieldGroupFormatter;

use Drupal\Component\Utility\Html;
use Drupal\field_group\FieldGroupFormatterBase;

/**
 * Plugin implementation of the 'html_element' formatter.
 *
 * @FieldGroupFormatter(
 *   id = "multistep_section",
 *   label = @Translation("Multistep Section"),
 *   description = @Translation("This fieldgroup renders a multistep section."),
 *   supported_contexts = {
 *     "form",
 *   }
 * )
 */
class MultistepSection extends FieldGroupFormatterBase {

  /**
   * {@inheritdoc}
   */
  public function process(&$element, $processed_object) {
    $classes = $this->getClasses();

    // Let's act like we're a details field group, at least superficially.
    $classes[] = 'field-group-details';
    $classes[] = 'required-fields';
    $element['#attached']['library'][] = 'field_group/formatter.details';
    $element['#attached']['library'][] = 'field_group/core';

    // Also add our own things.
    $element['#attached']['library'][] = 'monarch_multistep_field_group/custom-triggers';
    $classes[] = 'monarch-multistep-section';

    $element['#type'] = 'details';
    $element['#is_multistep_section'] = TRUE;
    $element['#title'] = $this->getLabel();
    $element['#open'] = FALSE;
    $element['#group_name'] = $this->group->group_name;
    $element['#entity_type'] = $this->group->entity_type;
    $element['#bundle'] = $this->group->bundle;
    $element['#show_empty_fields'] = TRUE;
    $element['#attributes']['class'] = $classes;

    if ($this->getSetting('id')) {
      $element['#id'] = Html::getUniqueId($this->getSetting('id'));
    }

    $element['reveal_next_button'] = [
      '#weight' => 9999,
      '#type' => 'html_tag',
      '#tag' => 'div',
      '#attributes' => [
        'class' => ['text-end'],
      ],
    ];

    $element['reveal_next_button']['button'] = [
      '#type' => 'button',
      '#value' => $this->t('Next'),
      '#attributes' => [
        'class' => [
          'btn',
          'btn-secondary',
          'monarch-multistep-next',
          'w-auto',
        ],
        ' type' => 'button',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function preRender(&$element, $rendering_object) {}

  /**
   * {@inheritdoc}
   */
  public function settingsForm() {
    $form = parent::settingsForm();

    unset($form['show_empty_fields']);

    return $form;
  }

}
